@@ -6,7 +6,7 @@ import asyncio
 import logging
 from operator import itemgetter
 from datetime import datetime, timedelta, timezone
-from inspect import Parameter, signature, isfunction, ismethod, iscoroutinefunction
+from inspect import Parameter, signature, iscoroutinefunction
 from typing import (
     Any,
     Optional,
@@ -125,7 +125,7 @@ class PaladinsAPI(DataCache):
 
     # solely for typing, __aexit__ exists in the Endpoint
     async def __aenter__(self) -> PaladinsAPI:
-        return self
+        return cast(PaladinsAPI, await super().__aenter__())
 
     async def close(self):
         """
@@ -199,7 +199,7 @@ class PaladinsAPI(DataCache):
             if pts_dict := next(  # pragma: no branch
                 (s for s in api_status if s["environment"] == "pts"), None
             ):
-                pts_dict["platform"] = pts_dict["environment"]  # type: ignore[arg-type]
+                pts_dict["platform"] = pts_dict["environment"]  # type: ignore[typeddict-item]
 
             # fetch from the StatusPage
             group: Optional[ComponentGroup]
@@ -257,9 +257,7 @@ class PaladinsAPI(DataCache):
     def register_status_callback(
         self,
         callback: Union[
-            None,
-            Callable[[ServerStatus], Union[Awaitable[Any], Any]],
-            Callable[[ServerStatus, ServerStatus], Union[Awaitable[Any], Any]],
+            None, Callable[[ServerStatus], Any], Callable[[ServerStatus, ServerStatus], Any],
         ],
         check_interval: timedelta = _CHECK_INTERVAL,
         recheck_interval: timedelta = _RECHECK_INTERVAL,
@@ -303,14 +301,14 @@ class PaladinsAPI(DataCache):
         Parameters
         ----------
         callback : Union[None,\
-                Callable[[ServerStatus], Union[Awaitable[Any], Any]],\
-                Callable[[ServerStatus, ServerStatus], Union[Awaitable[Any], Any]]]
+            Callable[[ServerStatus], Any],\
+            Callable[[ServerStatus, ServerStatus], Any]]
             The callback function you want to register. This can be either a normal function
-            or an async one, accepting either ``1`` or ``2`` positional-only arguments,
+            or an async one, accepting either ``1`` or ``2`` positional arguments,
             with any return type.\n
             Passing a new callback function, while one is already running,
             will overwrite the previous one and reset the timer.\n
-            Passing `None` stops the checking loop.
+            Passing `None` removes the callback and stops the checking loop.
         check_interval : timedelta
             The length of the interval used between Operational
             (all servers up, no limited access, not including PTS) server status checks.\n
@@ -333,7 +331,7 @@ class PaladinsAPI(DataCache):
                 self._status_task.cancel()
                 self._status_task = None
             return
-        if not (isfunction(callback) or ismethod(callback)):
+        if not callable(callback):
             raise TypeError("Callback has to be either a normal or async function")
         sig = signature(callback)
         arg_types = (Parameter.POSITIONAL_OR_KEYWORD, Parameter.POSITIONAL_ONLY)
@@ -1048,24 +1046,24 @@ class PaladinsAPI(DataCache):
 
     async def get_bounty(
         self, *, language: Optional[Language] = None
-    ) -> Tuple[BountyItem, List[BountyItem], List[BountyItem]]:
+    ) -> Tuple[List[BountyItem], List[BountyItem]]:
         """
-        Returns a 3-item tuple denoting the (current, upcoming, past) bounty store items, sorted
+        Returns a 2-item tuple denoting the (active, past) bounty store items, sorted
         by their expiration time.
 
         .. note:
 
-            The "upcoming" items list is sorted so that the first item is the one
-            that is going to appear next, with future items following. The "past" items list
-            is sorted so that the first item is the one that has most recently expired,
-            with older items following.
+            The "active" items list is sorted so that the first ``N`` items are the ones
+            that are currently available, with further items becoming available
+            once the current expire. ``N`` changes according to the in-game bounty store size.
+            The "past" items list is sorted so that the first item
+            is the one that has the most recently expired, with older items following.
 
         .. note:
 
-            Depending on the bounty store availability, the "current" item may have
-            already expired. If this happens, the `BountyItem.active` attribute of
-            the "current" item will be `False`, the "upcoming" items list will be empty,
-            and the "past" items list will contain the rest, as expected.
+            Depending on the bounty store availability, all active items may have already expired.
+            If this happens, the "active" list is going to be empty,
+            and the "past" items list will contain all expired items, as expected.
 
         Parameters
         ----------
@@ -1075,9 +1073,9 @@ class PaladinsAPI(DataCache):
 
         Returns
         -------
-        Tuple[BountyItem, List[BountyItem], List[BountyItem]]
-            An tuple containing the current bounty store item, followed by a list of upcoming
-            items, followed by a list of items that have already expired.
+        Tuple[List[BountyItem], List[BountyItem]]
+            An tuple containing a list of active bounty store items,
+            followed by a list of items that have already expired.
 
         Raises
         ------
@@ -1089,15 +1087,10 @@ class PaladinsAPI(DataCache):
         response = await self.request("getbountyitems")
         if not response:
             raise NotFound("Bounty items")
-        items = [BountyItem(self, cache_entry, d) for d in response]
+        items = [BountyItem(self, cache_entry, item_data) for item_data in response]
         idx: int = 0
-        # find the most recent inactive deal, then go back one index to get the current one
         for i, item in enumerate(items):  # pragma: no branch
-            if item.active:
-                continue
-            # check if Hi-Rez hasn't fucked up and there's at least one active skin,
-            # otherwise fall back idx to 0
-            if i > 0:  # pragma: no cover
-                idx = i - 1
-            break
-        return (items[idx], items[idx-len(items)-1::-1], items[idx+1:])  # noqa
+            if not item.active:
+                idx = i
+                break
+        return (items[idx-len(items)-1::-1], items[idx:])
