@@ -9,6 +9,7 @@ __all__ = [
     "Queue",
     "Rarity",
     "Region",
+    "Passive",
     "Activity",
     "Language",
     "Platform",
@@ -98,8 +99,8 @@ class EnumMeta(type):
         # Preprocess special attributes
         new_attrs: Dict[str, Any] = {}
         for k, v in attrs.copy().items():
-            if k.startswith("__") or hasattr(v, "__get__"):
-                # special attribute or descriptor, pass unchanged
+            if k.startswith("_") or hasattr(v, "__get__"):
+                # private or special attribute, or descriptor - pass unchanged
                 # remove from attrs, so we don't treat them as members later
                 new_attrs[k] = attrs.pop(k)
 
@@ -269,7 +270,6 @@ class Platform(Enum, default_value=0):
     Epic_Games
         Aliases: ``epic``.
     """
-
     Unknown         =  0
     PC              =  1
     hirez           =  1
@@ -295,6 +295,8 @@ class Platform(Enum, default_value=0):
     Discord         = 25
     Epic_Games      = 28
     epic            = 28
+    Amazon_Luna     = 30
+    luna            = 30
 
 
 class Region(Enum, default_value=0):
@@ -322,7 +324,6 @@ class Region(Enum, default_value=0):
     Japan
         Aliases: ``jp``, ``jpn``.
     """
-
     Unknown             = 0
     North_America       = 1
     na                  = 1
@@ -372,7 +373,6 @@ class Language(Enum):
     Turkish
         Aliases: ``tr``, ``tur``.
     """
-
     # Unknown  =  0
     English    =  1
     en         =  1
@@ -449,7 +449,6 @@ class Queue(Enum, default_value=0):
     Test_Maps
         Aliases: ``test``.
     """
-
     Unknown                  =   0
     Casual_Siege             = 424
     casual                   = 424
@@ -496,7 +495,8 @@ class Queue(Enum, default_value=0):
     Custom_Serpent_Beach                  = 440
     Custom_Shattered_Desert               = 487
     Custom_Splitstone_Quary               = 459
-    Custom_Stone_Keep                     = 423
+    Custom_Stone_Keep_Day                 = 10239
+    Custom_Stone_Keep_Night               = 10210
     Custom_Timber_Mill                    = 430
     Custom_Warders_Gate                   = 485
     Custom_Foremans_Rise_Onslaught        = 462
@@ -690,6 +690,7 @@ class Rank(_RankEnum):
     ``Platinum_IV``, ``Platinum_III``, ``Platinum_II``, ``Platinum_I``, ``Diamond_V``,
     ``Diamond_IV``, ``Diamond_III``, ``Diamond_II``, ``Diamond_I``, ``Master``, ``Grandmaster``.
     """
+    _ROMAN2INT = {"I": "1", "II": "2", "III": "3", "IV": "4", "V": "5"}
 
     Qualifying   =  0
     Bronze_V     =  1
@@ -723,18 +724,72 @@ class Rank(_RankEnum):
     @property
     def alt_name(self) -> str:
         """
-        Returns an alternative name of a rank, with the roman numeral replaced with an integer.
+        str: Returns an alternative name of a rank, with the roman numeral replaced
+        with an integer.
 
-        Example: "Silver IV" -> "Silver 4".
-
-        :type: str
+        Example: ``Silver IV`` -> ``Silver 4``.
         """
-        for roman in ("I", "II", "III", "IV", "V"):
-            if self.name.endswith(roman):
-                number = {"I": "1", "II": "2", "III": "3", "IV": "4", "V": "5"}[roman]
-                return self.name.replace(roman, number)
+        if ' ' in self.name:
+            tier, _, division = self.name.partition(' ')
+            return f"{tier} {self._ROMAN2INT[division]}"
         return self.name
 
+    @property
+    def tier(self) -> str:
+        """
+        str: Returns the rank's tier, one of: ``Qualifying``, ``Bronze``, ``Silver``, ``Gold``,
+        ``Platinum``, ``Diamond``, ``Master`` or ``Grandmaster``.
+        """
+        if ' ' in self.name:
+            tier, _, division = self.name.partition(' ')
+            return tier
+        return self.name
+
+    @property
+    def division(self) -> str:
+        """
+        str: Returns the rank's division, one of: ``I``, ``II``, ``III``, ``IV`` or ``V``.\n
+        If the rank has no divisions, returns the name unchanged:
+        ``Qualifying``, ``Master`` or ``Grandmaster``.
+        """
+        if ' ' in self.name:
+            tier, _, division = self.name.partition(' ')
+            return division
+        return self.name
+
+    @property
+    def alt_division(self) -> str:
+        """
+        str: Returns the rank's division as an integer, one of: ``1``, ``2``, ``3``,
+        ``4`` or ``5``.\n
+        If the rank has no divisions, returns the name unchanged:
+        ``Qualifying``, ``Master`` or ``Grandmaster``.
+        """
+        if ' ' in self.name:
+            tier, _, division = self.name.partition(' ')
+            return self._ROMAN2INT[division]
+        return self.name
+
+
+class Passive(Enum):
+    """
+    Passive enum. Represents an in-match passive ability. Currently applies only to Octavia.
+    Available at: `MatchLoadout.passive`.
+
+    Inherits from `Enum`.
+
+    Attributes
+    """
+    # Some champions appear to have other devices stored in there,
+    # but we don't care about that for now
+    # Wall_Climb = 23461  # Koga's Wall Climb
+    # DR     = 26716  # Yagorath's DR?
+    # Octavia's passives
+    Shield   = 26883
+    Credit   = 27051
+    Cooldown = 27052
+    Ultimate = 27053
+
 
 class DeviceType(Enum, default_value=0):
     """
@@ -754,7 +809,6 @@ class DeviceType(Enum, default_value=0):
     Talent
         The device of this type is a Talent.
     """
-
     Undefined = 0
     Item      = 1
     Card      = 2
@@ -808,7 +862,6 @@ class AbilityType(Enum, default_value=0):
         The ability does Area Damage.\n
         Aliases: ``aoe``.
     """
-
     Undefined     = 0
     Direct_Damage = 1
     direct        = 1
@@ -837,7 +890,6 @@ class Activity(Enum, default_value=5):
     Unknown
         The player's status is unknown.
     """
-
     Offline             = 0
     In_Lobby            = 1
     Character_Selection = 2
